@@ -145,7 +145,7 @@ heuristicOR <- function(S, g, root="00"){
 #' \item \code{F} (def.): corresponds to the harmonic mean between the average precision and recall
 #' \item \code{avF}: corresponds to the per-example \code{F-score} averaged across all the examples
 #' }
-#' @param rec.levels a vector with the desired recall levels (\code{def:} \code{from:0.1}, \code{to:0.9}, \code{by:0.1}) to compute the 
+#' @param recall.levels a vector with the desired recall levels (\code{def:} \code{from:0.1}, \code{to:0.9}, \code{by:0.1}) to compute the 
 #' the Precision at fixed Recall level (PXR)
 #' @param flat.file name of the file containing the flat scores matrix to be normalized or already normalized (without rda extension)
 #' @param ann.file name of the file containing the the label matrix of the examples (without rda extension)
@@ -163,7 +163,7 @@ heuristicOR <- function(S, g, root="00"){
 #' 	\enumerate{
 #' 		\item AUPRC results computed though \code{AUPRC.single.over.classes} (\code{\link{AUPRC}});
 #'		\item AUROC results computed through \code{AUROC.single.over.classes} (\code{\link{AUROC}}); 
-#' 		\item PXR results computed though \code{PXR.at.multiple.recall.levels.over.classes} (\code{\link{PXR}});
+#' 		\item PXR results computed though \code{precision.at.given.recall.levels.over.classes} (\code{\link{PXR}});
 #' 		\item FMM results computed though \code{compute.Fmeasure.multilabel} (\code{\link{FMM}}); 
 #' }}
 #' It is stored in the \code{perf.dir} directory.
@@ -178,16 +178,16 @@ heuristicOR <- function(S, g, root="00"){
 #' save(S, file=paste0(tmpdir,"scores.rda"));
 #' dag.dir <- flat.dir <- ann.dir <- tmpdir;
 #' hierScore.dir <- perf.dir <- tmpdir;
-#' rec.levels <- seq(from=0.1, to=1, by=0.1);
+#' recall.levels <- seq(from=0.25, to=1, by=0.25);
 #' dag.file <- "graph";
 #' flat.file <- "scores";
 #' ann.file <- "labels";
 #' Do.heuristic.methods(heuristic.fun="AND", norm=FALSE, norm.type="MaxNorm",
-#' folds=5, seed=23, n.round=3, f.criterion ="F", rec.levels=rec.levels, 
+#' folds=NULL, seed=23, n.round=3, f.criterion ="F", recall.levels=recall.levels, 
 #' flat.file=flat.file, ann.file=ann.file, dag.file=dag.file, flat.dir=flat.dir, 
 #' ann.dir=ann.dir, dag.dir=dag.dir, hierScore.dir=hierScore.dir, perf.dir=perf.dir);
 Do.heuristic.methods <- function(heuristic.fun="AND", norm=TRUE, norm.type=NULL, folds=5, seed=23, 
-	n.round=3, f.criterion ="F", rec.levels=seq(from=0.1, to=1, by=0.1), flat.file=flat.file, ann.file=ann.file,
+	n.round=3, f.criterion ="F", recall.levels=seq(from=0.1, to=1, by=0.1), flat.file=flat.file, ann.file=ann.file,
 	dag.file=dag.file, flat.dir=flat.dir, ann.dir=ann.dir, dag.dir=dag.dir, hierScore.dir=hierScore.dir, perf.dir=perf.dir){
 
 	## Setting Check
@@ -236,7 +236,7 @@ Do.heuristic.methods <- function(heuristic.fun="AND", norm=TRUE, norm.type=NULL,
 	## Compute FLAT PRC, AUC, PXR (average and per class) FMM (average and per-example) one-shoot or cross-validated 
 	PRC.flat <- AUPRC.single.over.classes(ann, S, folds=folds, seed=seed);
 	AUC.flat <- AUROC.single.over.classes(ann, S, folds=folds, seed=seed);
-	PXR.flat <- PXR.at.multiple.recall.levels.over.classes(ann, S, rec.levels=rec.levels, folds=folds, seed=seed);
+	PXR.flat <- precision.at.given.recall.levels.over.classes(ann, S, folds=folds, seed=seed, recall.levels=recall.levels);
 	FMM.flat <- compute.Fmeasure.multilabel(ann, S, n.round=n.round, f.criterion=f.criterion, verbose=FALSE, 
 		b.per.example=TRUE, folds=folds, seed=seed);
 	cat("FLAT PERFORMANCE: DONE", "\n");
@@ -253,7 +253,7 @@ Do.heuristic.methods <- function(heuristic.fun="AND", norm=TRUE, norm.type=NULL,
 	## Compute HIER PRC, AUC, PXR (average and per class) FMM (average and per-example) one-shoot or cross-validated 
 	PRC.hier <- AUPRC.single.over.classes(ann, S, folds=folds, seed=seed);
 	AUC.hier <- AUROC.single.over.classes(ann, S, folds=folds, seed=seed);
-	PXR.hier <- PXR.at.multiple.recall.levels.over.classes(ann, S, rec.levels=rec.levels, folds=folds, seed=seed);
+	PXR.hier <- precision.at.given.recall.levels.over.classes(ann, S, folds=folds, seed=seed, recall.levels=recall.levels);
 	FMM.hier <- compute.Fmeasure.multilabel(ann, S, n.round=n.round, f.criterion=f.criterion, verbose=FALSE, 
 		b.per.example=TRUE, folds=folds, seed=seed);
 	cat("HIERARCHICAL PERFORMANCE: DONE", "\n");
@@ -315,7 +315,7 @@ Do.heuristic.methods <- function(heuristic.fun="AND", norm=TRUE, norm.type=NULL,
 #' \item \code{F} (def.): corresponds to the harmonic mean between the average precision and recall
 #' \item \code{avF}: corresponds to the per-example \code{F-score} averaged across all the examples
 #' }
-#' @param rec.levels a vector with the desired recall levels (\code{def:} \code{from:0.1}, \code{to:0.9}, \code{by:0.1}) to compute the 
+#' @param recall.levels a vector with the desired recall levels (\code{def:} \code{from:0.1}, \code{to:0.9}, \code{by:0.1}) to compute the 
 #' the Precision at fixed Recall level (PXR)
 #' @param flat.file name of the file containing the flat scores matrix to be normalized or already normalized (without rda extension)
 #' @param ann.file name of the file containing the the label matrix of the examples (without rda extension)
@@ -336,7 +336,7 @@ Do.heuristic.methods <- function(heuristic.fun="AND", norm=TRUE, norm.type=NULL,
 #' 	\enumerate{
 #' 		\item AUPRC results computed though \code{AUPRC.single.over.classes} (\code{\link{AUPRC}});
 #'		\item AUROC results computed through \code{AUROC.single.over.classes} (\code{\link{AUROC}}); 
-#' 		\item PXR results computed though \code{PXR.at.multiple.recall.levels.over.classes} (\code{\link{PXR}});
+#' 		\item PXR results computed though \code{precision.at.given.recall.levels.over.classes} (\code{\link{PXR}});
 #' 		\item FMM results computed though \code{compute.Fmeasure.multilabel} (\code{\link{FMM}}); 
 #' }}
 #' It is stored in the \code{perf.dir} directory.
@@ -353,18 +353,18 @@ Do.heuristic.methods <- function(heuristic.fun="AND", norm=TRUE, norm.type=NULL,
 #' save(test.index, file=paste0(tmpdir,"test.index.rda"));
 #' ind.dir <- dag.dir <- flat.dir <- ann.dir <- tmpdir;
 #' hierScore.dir <- perf.dir <- tmpdir;
-#' rec.levels <- seq(from=0.1, to=1, by=0.1);
+#' recall.levels <- seq(from=0.25, to=1, by=0.25);
 #' ind.test.set <- "test.index";
 #' dag.file <- "graph";
 #' flat.file <- "scores";
 #' ann.file <- "labels";
 #' Do.heuristic.methods.holdout(heuristic.fun="MAX", norm=FALSE, norm.type="MaxNorm", 
-#' folds=NULL, seed=23, n.round=3, f.criterion ="F", rec.levels=rec.levels,
+#' folds=NULL, seed=23, n.round=3, f.criterion ="F", recall.levels=recall.levels,
 #' flat.file=flat.file, ann.file=ann.file, dag.file=dag.file, 
 #' ind.test.set=ind.test.set, ind.dir=ind.dir, flat.dir=flat.dir, ann.dir=ann.dir, 
 #' dag.dir=dag.dir, hierScore.dir=hierScore.dir, perf.dir=perf.dir);
 Do.heuristic.methods.holdout <- function(heuristic.fun="AND", norm=TRUE, norm.type=NULL, folds=5, seed=23, 
-	n.round=3, f.criterion ="F", rec.levels=seq(from=0.1, to=1, by=0.1), flat.file=flat.file, ann.file=ann.file, 
+	n.round=3, f.criterion ="F", recall.levels=seq(from=0.1, to=1, by=0.1), flat.file=flat.file, ann.file=ann.file, 
 	dag.file=dag.file, ind.test.set=ind.test.set, ind.dir=ind.dir, flat.dir=flat.dir, ann.dir=ann.dir, 
 	dag.dir=dag.dir, hierScore.dir=hierScore.dir, perf.dir=perf.dir){
 
@@ -423,7 +423,7 @@ Do.heuristic.methods.holdout <- function(heuristic.fun="AND", norm=TRUE, norm.ty
 	## Compute FLAT PRC, AUC, PXR (average and per class) FMM (average and per-example) one-shoot or cross-validated 
 	PRC.flat <- AUPRC.single.over.classes(ann, S, folds=folds, seed=seed);
 	AUC.flat <- AUROC.single.over.classes(ann, S, folds=folds, seed=seed);
-	PXR.flat <- PXR.at.multiple.recall.levels.over.classes(ann, S, rec.levels=rec.levels, folds=folds, seed=seed);
+	PXR.flat <- precision.at.given.recall.levels.over.classes(ann, S, folds=folds, seed=seed, recall.levels=recall.levels);
 	FMM.flat <- compute.Fmeasure.multilabel(ann, S, n.round=n.round, f.criterion=f.criterion, verbose=FALSE,
 		b.per.example=TRUE, folds=folds, seed=seed);
 	cat("FLAT PERFORMANCE: DONE", "\n");
@@ -440,7 +440,7 @@ Do.heuristic.methods.holdout <- function(heuristic.fun="AND", norm=TRUE, norm.ty
 	## Compute HIER PRC, AUC, PXR (average and per class) FMM (average and per-example) one-shoot or cross-validated 
 	PRC.hier <- AUPRC.single.over.classes(ann, S, folds=folds, seed=seed);
 	AUC.hier <- AUROC.single.over.classes(ann, S, folds=folds, seed=seed);
-	PXR.hier <- PXR.at.multiple.recall.levels.over.classes(ann, S, rec.levels=rec.levels, folds=folds, seed=seed);
+	PXR.hier <- precision.at.given.recall.levels.over.classes(ann, S, folds=folds, seed=seed, recall.levels=recall.levels);
 	FMM.hier <- compute.Fmeasure.multilabel(ann, S, n.round=n.round, f.criterion=f.criterion, verbose=FALSE, 
 		b.per.example=TRUE, folds=folds, seed=seed);
 	cat("HIERARCHICAL PERFORMANCE: DONE", "\n");
